import sys

try:
    from ._version import version as __version__
except ImportError:
    __version__ = "unknown"

try:
    if "google.colab" in sys.modules:
        from google.colab import output

        output.enable_custom_widget_manager()
except ImportError:
    pass

from .widget import HiGlassWidget


def _jupyter_labextension_paths():
    return [{"src": "labextension", "dest": "higlass-widget"}]


def _jupyter_nbextension_paths():
    return [
        {
            "section": "notebook",
            "src": "nbextension",
            "dest": "higlass-widget",
            "require": "higlass-widget/extension",
        }
    ]



import json
from pathlib import Path

from setuptools import setup
from jupyter_packaging import get_data_files, npm_builder, wrap_installers

here = Path(__file__).parent.resolve()

with (here / "package.json").open() as f:
    version = json.load(f)["version"]

# representative files that should exist after build
targets = [
    str(here / "higlass_widget" / "nbextension" / "index.js"),
    str(here / "higlass_widget" / "labextension" / "package.json"),
]

builder = npm_builder(build_cmd="build", npm="npm")

cmdclass = wrap_installers(
    pre_develop=builder,
    pre_dist=builder,
    ensured_targets=targets,
    skip_if_exists=targets,
)

data_files = get_data_files([
    (
        "share/jupyter/nbextensions/higlass-widget/",
        "higlass_widget/nbextension/",
        "*"
    ),
    (
        "share/jupyter/labextensions/higlass-widget/",
        "higlass_widget/labextension/",
        "**"
    ),
    (
        "etc/jupyter/nbconfig/notebook.d/",
        str(here),
        "higlass-widget.json",
    ),
])

if __name__ == "__main__":
    setup(version=version, cmdclass=cmdclass, data_files=data_files)



import json
from typing import Any, Dict

import ipywidgets
import traitlets.traitlets as t

from ._version import version


class HiGlassWidget(ipywidgets.DOMWidget):
    _model_name = t.Unicode("HiGlassModel").tag(sync=True)
    _model_module = t.Unicode("higlass-widget").tag(sync=True)
    _model_module_version = t.Unicode(version).tag(sync=True)

    _view_name = t.Unicode("HiGlassView").tag(sync=True)
    _view_module = t.Unicode("higlass-widget").tag(sync=True)
    _view_module_version = t.Unicode(version).tag(sync=True)

    _viewconf = t.Unicode("null").tag(sync=True)

    # readonly properties
    location = t.List(t.Union([t.Float(), t.Tuple()]), read_only=True).tag(sync=True)

    def __init__(self, viewconf: Dict[str, Any], **kwargs):
        super().__init__(_viewconf=json.dumps(viewconf), **kwargs)

    def reload(self, *items):
        msg = json.dumps(["reload", items])
        self.send(msg)

    def zoom_to(
        self,
        view_id: str,
        start1: int,
        end1: int,
        start2: int = None,
        end2: int = None,
        animate_time: int = 500,
    ):
        msg = json.dumps(["zoomTo", view_id, start1, end1, start2, end2, animate_time])
        self.send(msg)
